@@ -261,7 +261,7 @@ def update_yaxis_from_dict(fig, trace_dict):
                                  for t in vals['trace'] if hasattr(t, 'y')])
         ymin, ymax, step = get_new_axis_range(ax_data)
         # exception for very small range values
-
+        # don't update if ymin = ymax
         tick_steps = np.arange(ymin, ymax, step)
         if ymin < 0 and ymax > 0:
             # shift to include origin if negative values in range
@@ -314,6 +314,10 @@ def rescale_min_max_for_data_labels(ymin, ymax):
     rng = ymax-ymin
     print('before scaling', ymin, ymax)
     # rescale to add buffer for data labels
+    if ymin == ymax:
+        ymin *= .95
+        ymax *= 1.05
+
     if ymin >= 0 and ymax > 0:
         ymax += rng * .15
     if ymin < 0 and ymax <= 0:
